@@ -150,18 +150,23 @@ class _ResolutionLevel:
         with open(path + os.sep + "NDTiff.index", "rb") as index_file:
             data = index_file.read()
         entries = {}
-        while len(data) > 0:
+        position = 0
+        while position < len(data):
+            print("\rReading index... {:.1f}%       ".format(
+                100 * ( 1 - (len(data) - position) / len(data))), end="")
             index_entry = {}
-            (axes_length,) = struct.unpack("I", data[:4])
-            axes_str = data[4 : 4 + axes_length].decode("utf-8")
+            (axes_length,) = struct.unpack("I", data[position:position + 4])
+            axes_str = data[position + 4 : position + 4 + axes_length].decode("utf-8")
             axes = json.loads(axes_str)
-            data = data[4 + axes_length :]
-            (filename_length,) = struct.unpack("I", data[:4])
+            position += axes_length + 4
+            (filename_length,) = struct.unpack("I", data[position: position + 4])
             if filename_length == 0:
-                warnings.warn("Index appears to not have been properly terminated (the dataset may still work)")
+                warnings.warn(
+                    "Index appears to not have been properly terminated (the dataset may still work)"
+                )
                 break
-            index_entry["filename"] = data[4 : 4 + filename_length].decode("utf-8")
-            data = data[4 + filename_length :]
+            index_entry["filename"] = data[position + 4 : position + 4 + filename_length].decode("utf-8")
+            position += 4 + filename_length
             (
                 index_entry["pixel_offset"],
                 index_entry["image_width"],
@@ -171,8 +176,8 @@ class _ResolutionLevel:
                 index_entry["metadata_offset"],
                 index_entry["metadata_length"],
                 index_entry["metadata_compression"],
-            ) = struct.unpack("IIIIIIII", data[:32])
-            data = data[32:]
+            ) = struct.unpack("IIIIIIII", data[position: position + 32])
+            position += 32
             entries[frozenset(axes.items())] = index_entry
         print("\rFinshed reading index          ", end="")
         return entries
